==> tw-server-common-2.3.14-20230713.021636-1-sources.jar: com/elitesland/tw/tw5/server/prd/my/service/PrdUserServiceImpl.java <==
package com.elitesland.tw.tw5.server.prd.my.service;

import com.alibaba.fastjson.JSONObject;
import com.elitescloud.cloudt.core.annotation.TenantTransaction;
import com.elitescloud.cloudt.core.annotation.common.TenantIsolateType;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import com.elitescloud.cloudt.system.param.SysPasswordUpdate;
import com.elitescloud.cloudt.system.provider.SysUserRpcService;
import com.elitesland.tw.tw5.api.prd.app.vo.PrdUserDataForAppVO;
import com.elitesland.tw.tw5.api.prd.my.service.PrdUserService;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserCompositeVO;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserDataVO;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserRemindVO;
import com.elitesland.tw.tw5.api.prd.my.vo.TwRecentWorkVO;
import com.elitesland.tw.tw5.api.prd.org.vo.PrdOrgDataRefVO;
import com.elitesland.tw.tw5.api.prd.org.vo.PrdOrgEmployeeRefVO;
import com.elitesland.tw.tw5.api.prd.system.service.PrdSystemProblemFeedbackService;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemMenuVO;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemSelectionVO;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemShortcutVO;
import com.elitesland.tw.tw5.server.common.TwException;
import com.elitesland.tw.tw5.server.prd.common.CacheUtil;
import com.elitesland.tw.tw5.server.prd.common.FileUtil;
import com.elitesland.tw.tw5.server.prd.common.GlobalUtil;
import com.elitesland.tw.tw5.server.prd.common.functionEnum.FunctionSelectionEnum;
import com.elitesland.tw.tw5.server.prd.my.dao.PrdUserDAO;
import com.elitesland.tw.tw5.server.prd.my.entity.PrdUserRemindDO;
import com.elitesland.tw.tw5.server.prd.qixin.config.QiXinProperties;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 菜单管理service
 *
 * @author wangding
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class PrdUserServiceImpl implements PrdUserService {
    private final PrdUserDAO dao;
    private final CacheUtil cacheUtil;
    private final FileUtil fileUtil;
    private final PrdSystemProblemFeedbackService prdSystemProblemFeedbackService;
    @Autowired
    private SysUserRpcService sysUserService;
    @Value("${tw5.workflow.enabled:false}")
    private Boolean workflow_enabled;
    private final QiXinProperties qiXinProperties;


    @Override
    public List<PrdUserCompositeVO> queryUserComposite(Long userId) {
        List<PrdUserCompositeVO> prdUserCompositeVOS = dao.queryUserComposite(userId);
        prdUserCompositeVOS.forEach(compositeVO -> {
            compositeVO.setManageLevelName(cacheUtil.transferSystemSelection("org:employee:manage", compositeVO.getManageLevel()));
            compositeVO.setWorkTypeName(cacheUtil.transferSystemSelection("org:employee:worktype", compositeVO.getWorkType()));

            PrdSystemSelectionVO prdSystemSelectionVO = cacheUtil.transferSystemSelectionObj("org:employee:specialtylevel", compositeVO.getSpecialtyLevel());
            if (prdSystemSelectionVO != null) {
                compositeVO.setSpecialtyLevelName(prdSystemSelectionVO.getSelectionName());
                compositeVO.setEqvaRatio(BigDecimal.valueOf(100));
                if (StringUtils.hasText(prdSystemSelectionVO.getExtString1())) {
                    compositeVO.setEqvaRatio(new BigDecimal(String.valueOf(prdSystemSelectionVO.getExtString1())));
                }
            }
        });
        return prdUserCompositeVOS;
    }

    @Transactional
    @Override
    public PrdUserDataVO queryUserDetail() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataVO vo = dao.queryUserDetail(userId);
        vo.setHeadDatas(fileUtil.getFileDatas(vo.getHeadCodes()));
        // 组织角色
        vo.setOrgRoles(dao.queryRolesById(userId + ""));
        // 系统角色
        vo.setSystemRoles(cacheUtil.getSystemRoleCodes(userId));
        List<PrdSystemShortcutVO> shortcutVOs = dao.queryShortcutList();
        if (!CollectionUtils.isEmpty(shortcutVOs)) {
            if (StringUtils.hasText(vo.getShortcutIds())) {
                shortcutVOs.forEach(shortcutVO -> {
                            if (vo.getShortcutIds().contains(shortcutVO.getId() + "")) {
                                shortcutVO.setIsMy(0);
                            }
                        }
                );
            }
            vo.setShortcutVOs(shortcutVOs);
        }
        String ticket = UUID.randomUUID().toString();
        vo.setTicket(new String(Base64.encodeBase64(ticket.getBytes())));
        transferSystemSelection(vo);

        dao.updateTicket(vo.getId(), ticket);
        vo.setWorkflowEnabled(workflow_enabled);
        vo.setQxBEnabled(qiXinProperties.getEnabled());
        return vo;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public PrdUserDataVO getUserInfoBase() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataVO vo = dao.queryUserDetail(userId);
        // 组织角色
        vo.setOrgRoles(dao.queryRolesById(userId + ""));
        // 系统角色
        vo.setSystemRoles(cacheUtil.getSystemRoleCodes(userId));
        // 翻译
        transferSystemSelection(vo);
        vo.setWorkflowEnabled(workflow_enabled);
        vo.setQxBEnabled(qiXinProperties.getEnabled());
        return vo;
    }

    @Override
    public PrdUserDataForAppVO queryDetailForMobile() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataForAppVO vo = dao.queryUserDetailForApp(userId);
        vo.setJobsName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeJobs.getCode(), vo.getJobs()));
        vo.setSexName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeSex.getCode(), vo.getSex()));
        vo.setWorkflowEnabled(workflow_enabled);
        return vo;
    }

    @Transactional
    @Override
    public Long updateShortcut(String shortcutIds) {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.updateShortcut(userId, shortcutIds);
    }

    @Override
    public void updatePassword(String oldPassword, String newPassword) {
        if (StringUtils.hasText(oldPassword) && StringUtils.hasText(newPassword)) {
            Long userId = GlobalUtil.getLoginUserId();
            SysPasswordUpdate passwordUpdate = new SysPasswordUpdate();
            passwordUpdate.setUserId(userId);
            passwordUpdate.setCurrentPassword(new String(Base64.encodeBase64(oldPassword.getBytes())));
            passwordUpdate.setNewPassword(new String(Base64.encodeBase64(newPassword.getBytes())));
            sysUserService.updatePassword(passwordUpdate);
        } else {
            throw TwException.error("", "无效的密码");
        }

    }

    @Override
    public List<TwRecentWorkVO> findMyWork() {
        Long userId = GlobalUtil.getLoginUserId();
        List<TwRecentWorkVO> recentWorkVOList = new ArrayList<>();
        //问题反馈
        problemFeedback(recentWorkVOList, userId);
        return recentWorkVOList;
    }


    @Override
    public List<PrdUserRemindVO> findMyRemind() {
        Long userId = GlobalUtil.getLoginUserId();
        LocalDate newDate = LocalDate.now();

        List<PrdUserRemindVO> resRemindVOS = new ArrayList<>();
        List<PrdUserRemindVO> remindVOS = dao.queryReminds(userId);
        for (PrdUserRemindVO remindVO : remindVOS) {
            if (remindVO.getNoRemindDate() == null || !remindVO.getNoRemindDate().equals(newDate)) {
                String remindType = remindVO.getRemindType();
//                //待领取线索
//                if (remindType.equals(RemindTypeEnum.RECEIVED_LEAD.getCode())) {
//                    long num = crmLeadsService.countNotReceivedLeadsByUserId(userId);
//                    if (num > 0) {
//                        Map<String, Object> map = new HashMap<>();
//                        map.put("num", num);
//                        String remindContent = SpelUtil.parseStringExpression(remindVO.getRemindContent(), map);
//                        remindVO.setRemindContent(remindContent);
//                        resRemindVOS.add(remindVO);
//                    }
//                }
//                //待发布活动
//                if (remindType.equals(RemindTypeEnum.ACTIVITY_UNRELEASE.getCode())) {
//                    Map<String, Object> objectMap = activityservice.findActivityUnReleaseByUserId(userId);
//                    Long num = (Long) objectMap.get("num");
//                    if (num > 0) {
//                        Map<String, Object> map = new HashMap<>();
//                        map.put("num", num);
//                        String remindContent = SpelUtil.parseStringExpression(remindVO.getRemindContent(), map);
//                        remindVO.setRemindContent(remindContent);
//                        remindVO.setSurplusTime(objectMap.get("time") + "");
//                        resRemindVOS.add(remindVO);
//
//                    }
//
//                }

            }
        }
        return resRemindVOS;
    }

    @Transactional
    @Override
    public Boolean updateMyRemind(String remindType) {
        Long userId = GlobalUtil.getLoginUserId();
        LocalDate newDate = LocalDate.now();
        PrdUserRemindDO userRemindDO = dao.queryUserRemind(userId, remindType);
        if (userRemindDO == null) {
            userRemindDO = new PrdUserRemindDO();
            userRemindDO.setRemindType(remindType);
            userRemindDO.setUserId(userId);
        }
        userRemindDO.setNoRemindDate(newDate);
        dao.saveUserRemind(userRemindDO);
        return true;
    }

    @Override
    public void queryUserByTicket(HttpServletRequest request, HttpServletResponse response) {
        String ticket = request.getParameter("ticket");
        //对获取的加密的token进行解密：使用 Base64
        if (ticket != null && !ticket.isEmpty()) {
            ticket = new String(Base64.decodeBase64(ticket.getBytes()));
        }
        Map<String, Object> paramMap = new HashMap<>();
        JSONObject jsonObject = null;
        HttpSession session = request.getSession();
//        通过ticket查询用户信息
        PrdUserDataVO info = dao.queryUserByTicket(ticket);
        try {
            if (info == null) {
                paramMap.put("el-result-cod", "NG_UNSUPPORTED");
                paramMap.put("statusCode", "401");
                jsonObject = new JSONObject(paramMap);
                response.setStatus(401);
                session.setAttribute("paramMap", paramMap);
            }
            paramMap.put("app_login_type", "SSO");
            paramMap.put("app_login_id", info.getId());
            paramMap.put("app_login_email", info.getEmail());
            paramMap.put("app_login_ticket", ticket);
            paramMap.put("el-result-cod", "OK");
            paramMap.put("statusCode", "200");
            jsonObject = new JSONObject(paramMap);
            response.setStatus(200);
            session.setAttribute("paramMap", paramMap);
            response.getWriter().print(jsonObject);
        } catch (NullPointerException e) {
            try {
                response.getWriter().print(jsonObject);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public List<PrdOrgDataRefVO> queryOrgList() {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.queryOrgListByKey(userId);
    }

    @Override
    public List<PrdOrgEmployeeRefVO> queryLowListByKey(Long orgId) {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.queryLowListByKey(orgId, userId);
    }

    @TenantTransaction(isolateType = TenantIsolateType.DEFAULT)
    @Override
    public List<PrdSystemMenuVO> queryMenus() {
        List<PrdSystemMenuVO> menuVOS = dao.queryUsableList();

        GeneralUserDetails loginGeneralUser = GlobalUtil.getLoginGeneralUser();

        //List<Long> saleAdminUserIdsByRole = systemRoleDAO.queryUserIdByRoleCodes(Arrays.asList(RoleEnum.SYS.getCode()));
        // Boolean sysRole = cacheUtil.hasSystemRolePermission(Arrays.asList(RoleEnum.SYS.getCode()));
        if (loginGeneralUser.isSystemAdmin()) {
            return menuVOS;
        }
        if (loginGeneralUser.isTenantAdmin()) {
            return menuVOS.stream().filter(menuVO_ -> !menuVO_.getPortalRoute().contains("/tenancy")).collect(Collectors.toList());
        }
        List<Long> userMenuIds = dao.queryUserMenuIds(loginGeneralUser.getUserId());
//        if (userId.longValue() == 356948235909079040L) {
//            return menuVOS;
//        }
        return menuVOS.stream().filter(menuVO -> userMenuIds.indexOf(menuVO.getId()) >= 0).collect(Collectors.toList());
    }


    //问题反馈
    private void problemFeedback(List<TwRecentWorkVO> recentWorkVOList, long userId) {
        final long num = prdSystemProblemFeedbackService.findWorkProblemFeedbackByUserId(userId);
        if (num > 0) {
            recentWorkVOList.add(TwRecentWorkVO.of("问题反馈", num, TwRecentWorkVO.RecentWorkType.FEED_BACK.getCode()));
        }
    }

    //全局翻译
    void transferSystemSelection(PrdUserDataVO vo) {
        vo.setJobsName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeJobs.getCode(), vo.getJobs()));
    }


}

==> tw-server-common-2.4.7-20230828.075015-1-sources.jar: com/elitesland/tw/tw5/server/prd/my/service/PrdUserServiceImpl.java <==
package com.elitesland.tw.tw5.server.prd.my.service;

import com.alibaba.fastjson.JSONObject;
import com.elitescloud.cloudt.core.annotation.TenantTransaction;
import com.elitescloud.cloudt.core.annotation.common.TenantIsolateType;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import com.elitescloud.cloudt.system.param.SysPasswordUpdate;
import com.elitescloud.cloudt.system.provider.SysUserRpcService;
import com.elitesland.tw.tw5.api.prd.app.vo.PrdUserDataForAppVO;
import com.elitesland.tw.tw5.api.prd.my.service.PrdUserService;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserCompositeVO;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserDataVO;
import com.elitesland.tw.tw5.api.prd.my.vo.PrdUserRemindVO;
import com.elitesland.tw.tw5.api.prd.my.vo.TwRecentWorkVO;
import com.elitesland.tw.tw5.api.prd.org.vo.PrdOrgDataRefVO;
import com.elitesland.tw.tw5.api.prd.org.vo.PrdOrgEmployeeRefVO;
import com.elitesland.tw.tw5.api.prd.system.service.PrdSystemProblemFeedbackService;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemMenuVO;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemRoleVO;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemSelectionVO;
import com.elitesland.tw.tw5.api.prd.system.vo.PrdSystemShortcutVO;
import com.elitesland.tw.tw5.server.common.TwException;
import com.elitesland.tw.tw5.server.prd.common.CacheUtil;
import com.elitesland.tw.tw5.server.prd.common.FileUtil;
import com.elitesland.tw.tw5.server.prd.common.GlobalUtil;
import com.elitesland.tw.tw5.server.prd.common.functionEnum.FunctionSelectionEnum;
import com.elitesland.tw.tw5.server.prd.my.dao.PrdUserDAO;
import com.elitesland.tw.tw5.server.prd.my.entity.PrdUserRemindDO;
import com.elitesland.tw.tw5.server.prd.qixin.config.QiXinProperties;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 菜单管理service
 *
 * @author wangding
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class PrdUserServiceImpl implements PrdUserService {
    private final PrdUserDAO dao;
    private final CacheUtil cacheUtil;
    private final FileUtil fileUtil;
    private final PrdSystemProblemFeedbackService prdSystemProblemFeedbackService;
    @Autowired
    private SysUserRpcService sysUserService;
    @Value("${tw5.workflow.enabled:false}")
    private Boolean workflow_enabled;
    private final QiXinProperties qiXinProperties;


    @Override
    public List<PrdUserCompositeVO> queryUserComposite(Long userId) {
        List<PrdUserCompositeVO> prdUserCompositeVOS = dao.queryUserComposite(userId);
        prdUserCompositeVOS.forEach(compositeVO -> {
            compositeVO.setManageLevelName(cacheUtil.transferSystemSelection("org:employee:manage", compositeVO.getManageLevel()));
            compositeVO.setWorkTypeName(cacheUtil.transferSystemSelection("org:employee:worktype", compositeVO.getWorkType()));

            PrdSystemSelectionVO prdSystemSelectionVO = cacheUtil.transferSystemSelectionObj("org:employee:specialtylevel", compositeVO.getSpecialtyLevel());
            if (prdSystemSelectionVO != null) {
                compositeVO.setSpecialtyLevelName(prdSystemSelectionVO.getSelectionName());
                compositeVO.setEqvaRatio(BigDecimal.valueOf(100));
                if (StringUtils.hasText(prdSystemSelectionVO.getExtString1())) {
                    compositeVO.setEqvaRatio(new BigDecimal(String.valueOf(prdSystemSelectionVO.getExtString1())));
                }
            }
        });
        return prdUserCompositeVOS;
    }

    @Transactional
    @Override
    public PrdUserDataVO queryUserDetail() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataVO vo = dao.queryUserDetail(userId);
        vo.setHeadDatas(fileUtil.getFileDatas(vo.getHeadCodes()));
        // 组织角色
        vo.setOrgRoles(dao.queryRolesById(userId + ""));
        // 系统角色
        vo.setSystemRoles(cacheUtil.getSystemRoleCodes(userId));
        List<PrdSystemShortcutVO> shortcutVOs = dao.queryShortcutList();
        if (!CollectionUtils.isEmpty(shortcutVOs)) {
            if (StringUtils.hasText(vo.getShortcutIds())) {
                shortcutVOs.forEach(shortcutVO -> {
                            if (vo.getShortcutIds().contains(shortcutVO.getId() + "")) {
                                shortcutVO.setIsMy(0);
                            }
                        }
                );
            }
            vo.setShortcutVOs(shortcutVOs);
        }
        String ticket = UUID.randomUUID().toString();
        vo.setTicket(new String(Base64.encodeBase64(ticket.getBytes())));
        transferSystemSelection(vo);

        dao.updateTicket(vo.getId(), ticket);
        vo.setWorkflowEnabled(workflow_enabled);
        vo.setQxBEnabled(qiXinProperties.getEnabled());
        return vo;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public PrdUserDataVO getUserInfoBase() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataVO vo = dao.queryUserDetail(userId);
        // 组织角色
        vo.setOrgRoles(dao.queryRolesById(userId + ""));
        // 系统角色
        vo.setSystemRoles(cacheUtil.getSystemRoleCodes(userId));
        // 翻译
        transferSystemSelection(vo);
        vo.setWorkflowEnabled(workflow_enabled);
        vo.setQxBEnabled(qiXinProperties.getEnabled());
        return vo;
    }

    @Override
    public PrdUserDataForAppVO queryDetailForMobile() {
        Long userId = GlobalUtil.getLoginUserId();
        PrdUserDataForAppVO vo = dao.queryUserDetailForApp(userId);
        vo.setUserId(userId);
        vo.setJobsName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeJobs.getCode(), vo.getJobs()));
        vo.setSexName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeSex.getCode(), vo.getSex()));
        vo.setWorkflowEnabled(workflow_enabled);
        return vo;
    }

    @Transactional
    @Override
    public Long updateShortcut(String shortcutIds) {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.updateShortcut(userId, shortcutIds);
    }

    @Override
    public void updatePassword(String oldPassword, String newPassword) {
        if (StringUtils.hasText(oldPassword) && StringUtils.hasText(newPassword)) {
            Long userId = GlobalUtil.getLoginUserId();
            SysPasswordUpdate passwordUpdate = new SysPasswordUpdate();
            passwordUpdate.setUserId(userId);
            passwordUpdate.setCurrentPassword(new String(Base64.encodeBase64(oldPassword.getBytes())));
            passwordUpdate.setNewPassword(new String(Base64.encodeBase64(newPassword.getBytes())));
            sysUserService.updatePassword(passwordUpdate);
        } else {
            throw TwException.error("", "无效的密码");
        }

    }

    @Override
    public List<TwRecentWorkVO> findMyWork() {
        Long userId = GlobalUtil.getLoginUserId();
        List<TwRecentWorkVO> recentWorkVOList = new ArrayList<>();
        //问题反馈
        problemFeedback(recentWorkVOList, userId);
        return recentWorkVOList;
    }


    @Override
    public List<PrdUserRemindVO> findMyRemind() {
        Long userId = GlobalUtil.getLoginUserId();
        LocalDate newDate = LocalDate.now();

        List<PrdUserRemindVO> resRemindVOS = new ArrayList<>();
        List<PrdUserRemindVO> remindVOS = dao.queryReminds(userId);
        for (PrdUserRemindVO remindVO : remindVOS) {
            if (remindVO.getNoRemindDate() == null || !remindVO.getNoRemindDate().equals(newDate)) {
                String remindType = remindVO.getRemindType();
//                //待领取线索
//                if (remindType.equals(RemindTypeEnum.RECEIVED_LEAD.getCode())) {
//                    long num = crmLeadsService.countNotReceivedLeadsByUserId(userId);
//                    if (num > 0) {
//                        Map<String, Object> map = new HashMap<>();
//                        map.put("num", num);
//                        String remindContent = SpelUtil.parseStringExpression(remindVO.getRemindContent(), map);
//                        remindVO.setRemindContent(remindContent);
//                        resRemindVOS.add(remindVO);
//                    }
//                }
//                //待发布活动
//                if (remindType.equals(RemindTypeEnum.ACTIVITY_UNRELEASE.getCode())) {
//                    Map<String, Object> objectMap = activityservice.findActivityUnReleaseByUserId(userId);
//                    Long num = (Long) objectMap.get("num");
//                    if (num > 0) {
//                        Map<String, Object> map = new HashMap<>();
//                        map.put("num", num);
//                        String remindContent = SpelUtil.parseStringExpression(remindVO.getRemindContent(), map);
//                        remindVO.setRemindContent(remindContent);
//                        remindVO.setSurplusTime(objectMap.get("time") + "");
//                        resRemindVOS.add(remindVO);
//
//                    }
//
//                }

            }
        }
        return resRemindVOS;
    }

    @Transactional
    @Override
    public Boolean updateMyRemind(String remindType) {
        Long userId = GlobalUtil.getLoginUserId();
        LocalDate newDate = LocalDate.now();
        PrdUserRemindDO userRemindDO = dao.queryUserRemind(userId, remindType);
        if (userRemindDO == null) {
            userRemindDO = new PrdUserRemindDO();
            userRemindDO.setRemindType(remindType);
            userRemindDO.setUserId(userId);
        }
        userRemindDO.setNoRemindDate(newDate);
        dao.saveUserRemind(userRemindDO);
        return true;
    }

    @Override
    public void queryUserByTicket(HttpServletRequest request, HttpServletResponse response) {
        String ticket = request.getParameter("ticket");
        //对获取的加密的token进行解密：使用 Base64
        if (ticket != null && !ticket.isEmpty()) {
            ticket = new String(Base64.decodeBase64(ticket.getBytes()));
        }
        Map<String, Object> paramMap = new HashMap<>();
        JSONObject jsonObject = null;
        HttpSession session = request.getSession();
//        通过ticket查询用户信息
        PrdUserDataVO info = dao.queryUserByTicket(ticket);
        try {
            if (info == null) {
                paramMap.put("el-result-cod", "NG_UNSUPPORTED");
                paramMap.put("statusCode", "401");
                jsonObject = new JSONObject(paramMap);
                response.setStatus(401);
                session.setAttribute("paramMap", paramMap);
            }
            paramMap.put("app_login_type", "SSO");
            paramMap.put("app_login_id", info.getId());
            paramMap.put("app_login_email", info.getEmail());
            paramMap.put("app_login_ticket", ticket);
            paramMap.put("el-result-cod", "OK");
            paramMap.put("statusCode", "200");
            jsonObject = new JSONObject(paramMap);
            response.setStatus(200);
            session.setAttribute("paramMap", paramMap);
            response.getWriter().print(jsonObject);
        } catch (NullPointerException e) {
            try {
                response.getWriter().print(jsonObject);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public List<PrdOrgDataRefVO> queryOrgList() {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.queryOrgListByKey(userId);
    }

    @Override
    public List<PrdOrgEmployeeRefVO> queryLowListByKey(Long orgId) {
        Long userId = GlobalUtil.getLoginUserId();
        return dao.queryLowListByKey(orgId, userId);
    }

    @TenantTransaction(isolateType = TenantIsolateType.DEFAULT)
    @Override
    public List<PrdSystemMenuVO> queryMenus() {
        List<PrdSystemMenuVO> menuVOS = dao.queryUsableList();

        GeneralUserDetails loginGeneralUser = GlobalUtil.getLoginGeneralUser();

        //List<Long> saleAdminUserIdsByRole = systemRoleDAO.queryUserIdByRoleCodes(Arrays.asList(RoleEnum.SYS.getCode()));
        // Boolean sysRole = cacheUtil.hasSystemRolePermission(Arrays.asList(RoleEnum.SYS.getCode()));
        if (loginGeneralUser.isSystemAdmin()) {
            return menuVOS;
        }
        if (loginGeneralUser.isTenantAdmin()) {
            return menuVOS.stream().filter(menuVO_ -> !menuVO_.getPortalRoute().contains("/tenancy")).collect(Collectors.toList());
        }
        List<Long> userMenuIds = dao.queryUserMenuIds(loginGeneralUser.getUserId());
//        if (userId.longValue() == 356948235909079040L) {
//            return menuVOS;
//        }
        return menuVOS.stream().filter(menuVO -> userMenuIds.indexOf(menuVO.getId()) >= 0).collect(Collectors.toList());
    }

    @Override
    public List<PrdUserDataVO> queryPrdUserDataByOrgIdAndSystemRole(Long orgId, String systemRole) {
        return dao.queryPrdUserDataByOrgIdAndSystemRole(orgId,systemRole);
    }

    @Override
    public List<PrdSystemRoleVO> querySystemRoleByUserId(Long userId) {
        return dao.querySystemRoleByUserId(userId);
    }


    //问题反馈
    private void problemFeedback(List<TwRecentWorkVO> recentWorkVOList, long userId) {
        final long num = prdSystemProblemFeedbackService.findWorkProblemFeedbackByUserId(userId);
        if (num > 0) {
            recentWorkVOList.add(TwRecentWorkVO.of("问题反馈", num, TwRecentWorkVO.RecentWorkType.FEED_BACK.getCode()));
        }
    }

    //全局翻译
    void transferSystemSelection(PrdUserDataVO vo) {
        vo.setJobsName(cacheUtil.transferSystemSelection(FunctionSelectionEnum.EmployeeJobs.getCode(), vo.getJobs()));
    }


}
